@@ -1,14 +1,15 @@
+use hirofa_utils::js_utils::JsError;
 use std::fmt::{Error, Formatter};
 
-/// The EsError struct is used throughout this crate to represent errors
+/// The JsError struct is used throughout this crate to represent errors
 
-pub struct EsError {
+pub struct JsError {
     name: String,
     message: String,
     stack: String,
 }
 
-impl EsError {
+impl JsError {
     pub fn new(name: String, message: String, stack: String) -> Self {
         Self {
             name,
@@ -20,7 +21,7 @@ impl EsError {
         Self::new_string(err.to_string())
     }
     pub fn new_string(err: String) -> Self {
-        EsError {
+        JsError {
             name: "".to_string(),
             message: err,
             stack: "".to_string(),
@@ -37,7 +38,7 @@ impl EsError {
     }
 }
 
-impl std::fmt::Display for EsError {
+impl std::fmt::Display for JsError {
     fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error> {
         let e = format!("{}: {} at{}", self.name, self.message, self.stack);
         f.write_str(e.as_str())
