@@ -1,6 +1,4 @@
-use crate::eserror::EsError;
 use crate::esruntimebuilder::EsRuntimeBuilder;
-use crate::esscript::EsScript;
 use crate::esvalue::EsValueFacade;
 use crate::features;
 use crate::features::fetch::request::FetchRequest;
@@ -8,10 +6,17 @@ use crate::features::fetch::response::FetchResponse;
 use crate::quickjs_utils::{functions, objects};
 use crate::quickjscontext::QuickJsContext;
 use crate::quickjsruntime::{NativeModuleLoaderAdapter, QuickJsRuntime, ScriptModuleLoaderAdapter};
+use crate::valueref::JSValueRef;
 use hirofa_utils::eventloop::EventLoop;
+use hirofa_utils::js_utils::adapters::JsRealmAdapter;
+use hirofa_utils::js_utils::facades::{JsRuntimeFacade, JsValueFacade};
+use hirofa_utils::js_utils::JsError;
+use hirofa_utils::js_utils::Script;
 use hirofa_utils::task_manager::TaskManager;
 use libquickjs_sys as q;
+use std::collections::HashSet;
 use std::future::Future;
+use std::pin::Pin;
 use std::rc::Rc;
 use std::sync::{Arc, Weak};
 use tokio::task::JoinError;
@@ -24,12 +29,6 @@ lazy_static! {
 pub type FetchResponseProvider =
     dyn Fn(&FetchRequest) -> Box<dyn FetchResponse + Send> + Send + Sync + 'static;
 
-pub trait ScriptPreProcessor {
-    fn process(&self, script: EsScript) -> Result<EsScript, EsError> {
-        Ok(script)
-    }
-}
-
 impl Drop for EsRuntime {
     fn drop(&mut self) {
         log::trace!("> EsRuntime::drop");
@@ -45,10 +44,10 @@ impl Drop for EsRuntime {
 /// use quickjs_runtime::esruntimebuilder::EsRuntimeBuilder;
 /// let rt = EsRuntimeBuilder::new().build();
 /// ```
-
 pub struct EsRuntime {
     event_loop: EventLoop,
     fetch_response_provider: Option<Box<FetchResponseProvider>>,
+    js_contexts: HashSet<String>,
 }
 
 impl EsRuntime {
@@ -59,6 +58,7 @@ impl EsRuntime {
         let ret = Arc::new(Self {
             event_loop: EventLoop::new(),
             fetch_response_provider,
+            js_contexts: Default::default(),
         });
 
         ret.exe_task(|| {
@@ -264,7 +264,7 @@ impl EsRuntime {
     }
 
     /// Evaluate a script asynchronously
-    pub async fn eval(&self, script: EsScript) -> Result<EsValueFacade, EsError> {
+    pub async fn eval(&self, script: Script) -> Result<EsValueFacade, JsError> {
         self.add_rt_task_to_event_loop(|q_js_rt| {
             let q_ctx = q_js_rt.get_main_context();
             let res = q_ctx.eval(script);
@@ -280,13 +280,13 @@ impl EsRuntime {
     /// # example
     /// ```rust
     /// use quickjs_runtime::esruntimebuilder::EsRuntimeBuilder;
-    /// use quickjs_runtime::esscript::EsScript;
+    /// use hirofa_utils::js_utils::Script;
     /// let rt = EsRuntimeBuilder::new().build();
-    /// let script = EsScript::new("my_file.es", "(9 * 3);");
+    /// let script = Script::new("my_file.es", "(9 * 3);");
     /// let res = rt.eval_sync(script).ok().expect("script failed");
     /// assert_eq!(res.get_i32(), 27);
     /// ```
-    pub fn eval_sync(&self, script: EsScript) -> Result<EsValueFacade, EsError> {
+    pub fn eval_sync(&self, script: Script) -> Result<EsValueFacade, JsError> {
         self.exe_rt_task_in_event_loop(move |q_js_rt| {
             let q_ctx = q_js_rt.get_main_context();
             let res = q_ctx.eval(script);
@@ -311,12 +311,12 @@ impl EsRuntime {
     /// # example
     /// ```rust
     /// use quickjs_runtime::esruntimebuilder::EsRuntimeBuilder;
-    /// use quickjs_runtime::esscript::EsScript;
     /// use quickjs_runtime::es_args;
     /// use quickjs_runtime::esvalue::EsValueConvertible;
     /// use quickjs_runtime::esvalue::EsValueFacade;
+    /// use hirofa_utils::js_utils::Script;
     /// let rt = EsRuntimeBuilder::new().build();
-    /// let script = EsScript::new("my_file.es", "this.com = {my: {methodA: function(a, b, someStr, someBool){return a*b;}}};");
+    /// let script = Script::new("my_file.es", "this.com = {my: {methodA: function(a, b, someStr, someBool){return a*b;}}};");
     /// rt.eval_sync(script).ok().expect("script failed");
     /// let res = rt.call_function_sync(vec!["com", "my"], "methodA", vec![7i32.to_es_value_facade(), 5i32.to_es_value_facade(), "abc".to_string().to_es_value_facade(), true.to_es_value_facade()]).ok().expect("func failed");
     /// assert_eq!(res.get_i32(), 35);
@@ -326,7 +326,7 @@ impl EsRuntime {
         namespace: Vec<&'static str>,
         func_name: &str,
         mut arguments: Vec<EsValueFacade>,
-    ) -> Result<EsValueFacade, EsError> {
+    ) -> Result<EsValueFacade, JsError> {
         let func_name_string = func_name.to_string();
 
         self.exe_rt_task_in_event_loop(move |q_js_rt| {
@@ -350,10 +350,10 @@ impl EsRuntime {
     /// # example
     /// ```rust
     /// use quickjs_runtime::esruntimebuilder::EsRuntimeBuilder;
-    /// use quickjs_runtime::esscript::EsScript;
     /// use quickjs_runtime::esvalue::EsValueConvertible;
+    /// use hirofa_utils::js_utils::Script;
     /// let rt = EsRuntimeBuilder::new().build();
-    /// let script = EsScript::new("my_file.es", "this.com = {my: {methodA: function(a, b){return a*b;}}};");
+    /// let script = Script::new("my_file.es", "this.com = {my: {methodA: function(a, b){return a*b;}}};");
     /// rt.eval_sync(script).ok().expect("script failed");
     /// rt.call_function(vec!["com", "my"], "methodA".to_string(), vec![7.to_es_value_facade(), 5.to_es_value_facade()]);
     /// ```
@@ -362,7 +362,7 @@ impl EsRuntime {
         namespace: Vec<&'static str>,
         func_name: String,
         mut arguments: Vec<EsValueFacade>,
-    ) -> Result<EsValueFacade, EsError> {
+    ) -> Result<EsValueFacade, JsError> {
         let func_name_string = func_name.to_string();
 
         self.add_rt_task_to_event_loop(move |q_js_rt| {
@@ -393,13 +393,13 @@ impl EsRuntime {
     /// import {util} from 'file.mes';
     /// console.log(util(1, 2, 3));
     /// ```
-    /// please note that the module is cached under the absolute path you passed in the EsScript object
+    /// please note that the module is cached under the absolute path you passed in the Script object
     /// and thus you should take care to make the path unique (hence the absolute_ name)
     /// also to use this you need to build the EsRuntime with a module loader closure
     /// # example
     /// ```rust
     /// use quickjs_runtime::esruntimebuilder::EsRuntimeBuilder;
-    /// use quickjs_runtime::esscript::EsScript;
+    /// use hirofa_utils::js_utils::Script;
     /// use quickjs_runtime::esvalue::EsValueConvertible;
     /// use quickjs_runtime::quickjsruntime::ScriptModuleLoader;
     /// struct TestModuleLoader {}
@@ -413,11 +413,11 @@ impl EsRuntime {
     ///     }
     /// }
     /// let rt = EsRuntimeBuilder::new().script_module_loader(Box::new(TestModuleLoader{})).build();
-    /// let script = EsScript::new("/opt/files/my_module.mes", "import {util} from 'other_module.mes';\n
+    /// let script = Script::new("/opt/files/my_module.mes", "import {util} from 'other_module.mes';\n
     /// console.log(util(1, 2, 3));");
     /// rt.eval_module(script);
     /// ```
-    pub async fn eval_module(&self, script: EsScript) {
+    pub async fn eval_module(&self, script: Script) {
         self.add_rt_task_to_event_loop(|q_js_rt| {
             let q_ctx = q_js_rt.get_main_context();
             let res = q_ctx.eval_module(script);
@@ -430,7 +430,7 @@ impl EsRuntime {
     }
 
     /// evaluate a module and return result synchronously
-    pub fn eval_module_sync(&self, script: EsScript) -> Result<EsValueFacade, EsError> {
+    pub fn eval_module_sync(&self, script: Script) -> Result<EsValueFacade, JsError> {
         self.exe_rt_task_in_event_loop(move |q_js_rt| {
             let q_ctx = q_js_rt.get_main_context();
             let res = q_ctx.eval_module(script);
@@ -446,13 +446,13 @@ impl EsRuntime {
     /// # example
     /// ```rust
     /// use quickjs_runtime::esruntimebuilder::EsRuntimeBuilder;
-    /// use quickjs_runtime::esscript::EsScript;
+    /// use hirofa_utils::js_utils::Script;
     /// use quickjs_runtime::quickjs_utils::primitives;
     /// let rt = EsRuntimeBuilder::new().build();
     /// let res = rt.exe_rt_task_in_event_loop(|q_js_rt| {
     ///     let q_ctx = q_js_rt.get_main_context();
     ///     // here you are in the worker thread and you can use the quickjs_utils
-    ///     let val_ref = q_ctx.eval(EsScript::new("test.es", "(11 * 6);")).ok().expect("script failed");
+    ///     let val_ref = q_ctx.eval(Script::new("test.es", "(11 * 6);")).ok().expect("script failed");
     ///     primitives::to_i32(&val_ref).ok().expect("could not get i32")
     /// });
     /// assert_eq!(res, 66);
@@ -469,7 +469,7 @@ impl EsRuntime {
     /// # Example
     /// ```rust
     /// use quickjs_runtime::esruntimebuilder::EsRuntimeBuilder;
-    /// use quickjs_runtime::esscript::EsScript;
+    /// use hirofa_utils::js_utils::Script;
     /// use quickjs_runtime::quickjs_utils::primitives;
     /// use quickjs_runtime::esvalue::{EsValueFacade, EsValueConvertible};
     /// let rt = EsRuntimeBuilder::new().build();
@@ -478,7 +478,7 @@ impl EsRuntime {
     ///     let b = args[1].get_i32();
     ///     Ok((a * b).to_es_value_facade())
     /// });
-    /// let res = rt.eval_sync(EsScript::new("test.es", "let a = com.mycompany.util.methodA(13, 17); a * 2;")).ok().expect("script failed");
+    /// let res = rt.eval_sync(Script::new("test.es", "let a = com.mycompany.util.methodA(13, 17); a * 2;")).ok().expect("script failed");
     /// assert_eq!(res.get_i32(), (13*17*2));
     /// ```
     pub fn set_function<F>(
@@ -486,9 +486,9 @@ impl EsRuntime {
         namespace: Vec<&'static str>,
         name: &str,
         function: F,
-    ) -> Result<(), EsError>
+    ) -> Result<(), JsError>
     where
-        F: Fn(&QuickJsContext, Vec<EsValueFacade>) -> Result<EsValueFacade, EsError>
+        F: Fn(&QuickJsContext, Vec<EsValueFacade>) -> Result<EsValueFacade, JsError>
             + Send
             + 'static,
     {
@@ -552,15 +552,15 @@ impl EsRuntime {
     /// # Example
     /// ```
     /// use quickjs_runtime::esruntimebuilder::EsRuntimeBuilder;
-    /// use quickjs_runtime::esscript::EsScript;
+    /// use hirofa_utils::js_utils::Script;
     /// let rt = EsRuntimeBuilder::new().build();
     /// rt.create_context("my_context");
     /// rt.exe_rt_task_in_event_loop(|q_js_rt| {
     ///    let my_ctx = q_js_rt.get_context("my_context");
-    ///    my_ctx.eval(EsScript::new("ctx_test.es", "this.myVar = 'only exists in my_context';"));
+    ///    my_ctx.eval(Script::new("ctx_test.es", "this.myVar = 'only exists in my_context';"));
     /// });
     /// ```
-    pub fn create_context(&self, id: &str) -> Result<(), EsError> {
+    pub fn create_context(&self, id: &str) -> Result<(), JsError> {
         let id = id.to_string();
         self.event_loop
             .exe(move || QuickJsRuntime::create_context(id.as_str()))
@@ -574,11 +574,191 @@ impl EsRuntime {
     }
 }
 
+impl JsRuntimeFacade for EsRuntime {
+    type JsRuntimeAdapterType = QuickJsRuntime;
+
+    fn js_realm_create(&mut self, name: &str) -> Result<(), JsError> {
+        self.create_context(name).map(|_| {
+            self.js_contexts.insert(name.to_string());
+        })
+    }
+
+    fn js_realm_destroy(&mut self, _name: &str) -> Result<(), JsError> {
+        todo!()
+    }
+
+    fn js_realm_has(&mut self, name: &str) -> Result<bool, JsError> {
+        Ok(self.js_contexts.contains(name))
+    }
+
+    fn js_loop_sync<
+        R: Send + 'static,
+        C: FnOnce(&Self::JsRuntimeAdapterType) -> R + Send + 'static,
+    >(
+        &self,
+        consumer: C,
+    ) -> R {
+        self.exe_rt_task_in_event_loop(consumer)
+    }
+
+    fn js_loop<R: Send + 'static, C: FnOnce(&Self::JsRuntimeAdapterType) -> R + Send + 'static>(
+        &self,
+        consumer: C,
+    ) -> Pin<Box<dyn Future<Output = R> + Send>> {
+        Box::pin(self.add_rt_task_to_event_loop(consumer))
+    }
+
+    fn js_loop_void<C: FnOnce(&Self::JsRuntimeAdapterType) + Send + 'static>(&self, consumer: C) {
+        self.add_rt_task_to_event_loop_void(consumer)
+    }
+
+    #[allow(clippy::type_complexity)]
+    fn js_eval(
+        &self,
+        realm_name: Option<&str>,
+        script: Script,
+    ) -> Pin<Box<dyn Future<Output = Result<Box<dyn JsValueFacade>, JsError>>>> {
+        self.js_loop_realm(realm_name, |_rt, realm| {
+            realm
+                .js_eval(script)
+                .map(|jsvr| realm.to_js_value_facade(&jsvr))
+        })
+    }
+
+    #[warn(clippy::type_complexity)]
+    fn js_function_invoke_sync(
+        &self,
+        realm_name: Option<&str>,
+        namespace: &[&str],
+        method_name: &str,
+        args: Vec<Box<dyn JsValueFacade>>,
+    ) -> Result<Box<dyn JsValueFacade>, JsError> {
+        let movable_namespace: Vec<String> = namespace.iter().map(|s| s.to_string()).collect();
+        let movable_method_name = method_name.to_string();
+
+        self.js_loop_realm_sync(realm_name, move |_rt, realm| {
+            let args_adapters: Vec<JSValueRef> = args
+                .into_iter()
+                .map(|jsvf| {
+                    realm
+                        .from_js_value_facade(&*jsvf)
+                        .ok()
+                        .expect("conversion failed")
+                })
+                .collect();
+
+            let namespace = movable_namespace
+                .iter()
+                .map(|s| s.as_str())
+                .collect::<Vec<&str>>();
+
+            let res = realm
+                .js_function_invoke_by_name(
+                    namespace.as_slice(),
+                    movable_method_name.as_str(),
+                    args_adapters.as_slice(),
+                )
+                .map(|jsvr| realm.to_js_value_facade(&jsvr));
+
+            res
+        })
+    }
+
+    #[allow(clippy::type_complexity)]
+    fn js_function_invoke(
+        &self,
+        realm_name: Option<&str>,
+        namespace: &[&str],
+        method_name: &str,
+        args: Vec<Box<dyn JsValueFacade>>,
+    ) -> Pin<Box<dyn Future<Output = Result<Box<dyn JsValueFacade>, JsError>>>> {
+        let movable_namespace: Vec<String> = namespace.iter().map(|s| s.to_string()).collect();
+        let movable_method_name = method_name.to_string();
+
+        self.js_loop_realm(realm_name, move |_rt, realm| {
+            let args_adapters: Vec<JSValueRef> = args
+                .into_iter()
+                .map(|jsvf| {
+                    realm
+                        .from_js_value_facade(&*jsvf)
+                        .ok()
+                        .expect("conversion failed")
+                })
+                .collect();
+
+            let namespace = movable_namespace
+                .iter()
+                .map(|s| s.as_str())
+                .collect::<Vec<&str>>();
+
+            let res = realm
+                .js_function_invoke_by_name(
+                    namespace.as_slice(),
+                    movable_method_name.as_str(),
+                    args_adapters.as_slice(),
+                )
+                .map(|jsvr| realm.to_js_value_facade(&jsvr));
+
+            res
+        })
+    }
+
+    fn js_function_invoke_void(
+        &self,
+        realm_name: Option<&str>,
+        namespace: &[&str],
+        method_name: &str,
+        args: Vec<Box<dyn JsValueFacade>>,
+    ) {
+        let movable_namespace: Vec<String> = namespace.iter().map(|s| s.to_string()).collect();
+        let movable_method_name = method_name.to_string();
+
+        self.js_loop_realm_void(realm_name, move |_rt, realm| {
+            let args_adapters: Vec<JSValueRef> = args
+                .into_iter()
+                .map(|jsvf| {
+                    realm
+                        .from_js_value_facade(&*jsvf)
+                        .ok()
+                        .expect("conversion failed")
+                })
+                .collect();
+
+            let namespace = movable_namespace
+                .iter()
+                .map(|s| s.as_str())
+                .collect::<Vec<&str>>();
+
+            let res = realm
+                .js_function_invoke_by_name(
+                    namespace.as_slice(),
+                    movable_method_name.as_str(),
+                    args_adapters.as_slice(),
+                )
+                .map(|jsvr| realm.to_js_value_facade(&jsvr));
+
+            match res {
+                Ok(_) => {
+                    log::trace!(
+                        "js_function_invoke_void succeeded: {}",
+                        movable_method_name.as_str()
+                    );
+                }
+                Err(err) => {
+                    log::trace!(
+                        "js_function_invoke_void failed: {}: {}",
+                        movable_method_name.as_str(),
+                        err
+                    );
+                }
+            }
+        })
+    }
+}
+
 #[cfg(test)]
 pub mod tests {
-    use crate::eserror::EsError;
     use crate::esruntime::EsRuntime;
-    use crate::esscript::EsScript;
     use crate::esvalue::{EsValueConvertible, EsValueFacade};
     use crate::quickjs_utils::{primitives, promises};
     use crate::quickjscontext::QuickJsContext;
@@ -586,6 +766,8 @@ pub mod tests {
     use crate::valueref::JSValueRef;
     use backtrace::Backtrace;
     use futures::executor::block_on;
+    use hirofa_utils::js_utils::JsError;
+    use hirofa_utils::js_utils::Script;
     use log::debug;
     use log::LevelFilter;
     use std::panic;
@@ -685,7 +867,7 @@ pub mod tests {
         let rt = init_test_rt();
         let res = rt.set_function(vec!["nl", "my", "utils"], "methodA", |_q_ctx, args| {
             if args.len() != 2 || !args.get(0).unwrap().is_i32() || !args.get(1).unwrap().is_i32() {
-                Err(EsError::new_str(
+                Err(JsError::new_str(
                     "i'd realy like 2 args of the int32 kind please",
                 ))
             } else {
@@ -702,7 +884,7 @@ pub mod tests {
             }
         }
 
-        let res = rt.eval_sync(EsScript::new(
+        let res = rt.eval_sync(Script::new(
             "test_func.es",
             "(nl.my.utils.methodA(13, 56));",
         ));
@@ -721,7 +903,7 @@ pub mod tests {
     #[test]
     fn test_eval_sync() {
         let rt: Arc<EsRuntime> = init_test_rt();
-        let res = rt.eval_sync(EsScript::new("test.es", "console.log('foo bar');"));
+        let res = rt.eval_sync(Script::new("test.es", "console.log('foo bar');"));
 
         match res {
             Ok(_) => {}
@@ -731,7 +913,7 @@ pub mod tests {
         }
 
         let res = rt
-            .eval_sync(EsScript::new("test.es", "(2 * 7);"))
+            .eval_sync(Script::new("test.es", "(2 * 7);"))
             .ok()
             .expect("script failed");
 
@@ -746,7 +928,7 @@ pub mod tests {
         rt.exe_rt_task_in_event_loop(|q_js_rt| {
             //q_js_rt.run_pending_jobs_if_any();
             let q_ctx = q_js_rt.get_main_context();
-            let r = q_ctx.eval(EsScript::new(
+            let r = q_ctx.eval(Script::new(
                 "test_async.es",
                 "let f = async function(){let p = new Promise((resolve, reject) => {resolve(12345);}); const p2 = await p; return p2}; f();",
             )).ok().unwrap();
@@ -776,7 +958,7 @@ pub mod tests {
     fn test_eval_await() {
         let rt: Arc<EsRuntime> = init_test_rt();
 
-        let res = rt.eval_sync(EsScript::new(
+        let res = rt.eval_sync(Script::new(
             "test_async.es",
             "{let f = async function(){let p = new Promise((resolve, reject) => {resolve(12345);}); const p2 = await p; return p2}; f()};",
         ));
@@ -802,7 +984,7 @@ pub mod tests {
     fn test_promise() {
         let rt: Arc<EsRuntime> = init_test_rt();
 
-        let res = rt.eval_sync(EsScript::new(
+        let res = rt.eval_sync(Script::new(
             "testp2.es",
             "let test_promise_P = (new Promise(function(res, rej) {console.log('before res');res(123);console.log('after res');}).then(function (a) {console.log('prom ressed to ' + a);}).catch(function(x) {console.log('p.ca ex=' + x);}))",
         ));
@@ -820,7 +1002,7 @@ pub mod tests {
 
         let rt = init_test_rt();
         debug!("test static import");
-        let res: Result<EsValueFacade, EsError> = rt.eval_module_sync(EsScript::new(
+        let res: Result<EsValueFacade, JsError> = rt.eval_module_sync(Script::new(
             "test.es",
             "import {foo} from 'test_module.mes';\n console.log('static imp foo = ' + foo);",
         ));
@@ -835,7 +1017,7 @@ pub mod tests {
         }
 
         debug!("test dynamic import");
-        let res: Result<EsValueFacade, EsError> = rt.eval_sync(EsScript::new(
+        let res: Result<EsValueFacade, JsError> = rt.eval_sync(Script::new(
             "test_dyn.es",
             "console.log('about to load dynamic module');let dyn_p = import('test_module.mes');dyn_p.then(function (some) {console.log('after dyn');console.log('after dyn ' + typeof some);console.log('mltpl 5, 7 = ' + some.mltpl(5, 7));});dyn_p.catch(function (x) {console.log('imp.cat x=' + x);});console.log('dyn done');",
         ));
@@ -855,7 +1037,7 @@ pub mod tests {
 
     async fn test_async1() -> i32 {
         let rt = init_test_rt();
-        let a = rt.eval(EsScript::new("test_async.es", "122 + 1;")).await;
+        let a = rt.eval(Script::new("test_async.es", "122 + 1;")).await;
         a.ok().expect("script failed").get_i32()
     }
 
