@@ -1,8 +1,7 @@
-use crate::eserror::EsError;
 use crate::esruntime::EsRuntime;
 use crate::quickjs_utils::arrays::{get_element_q, get_length_q, is_array_q};
 use crate::quickjs_utils::dates::is_date_q;
-use crate::quickjs_utils::errors::{error_to_eserror, is_error_q};
+use crate::quickjs_utils::errors::{error_to_js_error, is_error_q};
 use crate::quickjs_utils::functions::{is_function_q, new_function_q};
 use crate::quickjs_utils::json::stringify_q;
 use crate::quickjs_utils::objects::{get_property_names_q, get_property_q};
@@ -17,6 +16,7 @@ use futures::executor::block_on;
 use futures::task::{Context, Poll};
 use hirofa_utils::auto_id_map::AutoIdMap;
 use hirofa_utils::debug_mutex::DebugMutex;
+use hirofa_utils::js_utils::JsError;
 use std::cell::RefCell;
 use std::collections::HashMap;
 use std::fmt::{Debug, Error, Formatter};
@@ -97,10 +97,10 @@ impl<R> Future for TaskFuture<R> {
 pub type EsValueFacadeFuture<R, E> = TaskFuture<Result<R, E>>;
 
 pub type PromiseReactionType =
-    Option<Box<dyn Fn(EsValueFacade) -> Result<EsValueFacade, EsError> + Send + 'static>>;
+    Option<Box<dyn Fn(EsValueFacade) -> Result<EsValueFacade, JsError> + Send + 'static>>;
 
 pub trait EsValueConvertible {
-    fn as_js_value(&mut self, q_ctx: &QuickJsContext) -> Result<JSValueRef, EsError>;
+    fn as_js_value(&mut self, q_ctx: &QuickJsContext) -> Result<JSValueRef, JsError>;
 
     #[allow(clippy::wrong_self_convention)]
     fn to_es_value_facade(self) -> EsValueFacade
@@ -147,22 +147,22 @@ pub trait EsValueConvertible {
     fn is_function(&self) -> bool {
         false
     }
-    fn invoke_function_sync(&self, _args: Vec<EsValueFacade>) -> Result<EsValueFacade, EsError> {
+    fn invoke_function_sync(&self, _args: Vec<EsValueFacade>) -> Result<EsValueFacade, JsError> {
         panic!("i am not a function");
     }
     fn invoke_function(
         &self,
         _args: Vec<EsValueFacade>,
-    ) -> EsValueFacadeFuture<EsValueFacade, EsError> {
+    ) -> EsValueFacadeFuture<EsValueFacade, JsError> {
         panic!("i am not a function");
     }
     fn invoke_function_batch_sync(
         &self,
         _args: Vec<Vec<EsValueFacade>>,
-    ) -> Vec<Result<EsValueFacade, EsError>> {
+    ) -> Vec<Result<EsValueFacade, JsError>> {
         panic!("i am not a function");
     }
-    fn invoke_function_batch(&self, _args: Vec<Vec<EsValueFacade>>) -> Result<(), EsError> {
+    fn invoke_function_batch(&self, _args: Vec<Vec<EsValueFacade>>) -> Result<(), JsError> {
         panic!("i am not a function");
     }
     fn is_promise(&self) -> bool {
@@ -179,31 +179,31 @@ pub trait EsValueConvertible {
         _then: PromiseReactionType,
         _catch: PromiseReactionType,
         _finally: Option<Box<dyn Fn() + Send + 'static>>,
-    ) -> Result<(), EsError> {
+    ) -> Result<(), JsError> {
         panic!("i am not a promise")
     }
     fn is_object(&self) -> bool {
         false
     }
-    fn get_object(&self) -> Result<HashMap<String, EsValueFacade>, EsError> {
+    fn get_object(&self) -> Result<HashMap<String, EsValueFacade>, JsError> {
         panic!("i am not an object");
     }
     fn is_array(&self) -> bool {
         false
     }
-    fn get_array(&self) -> Result<Vec<EsValueFacade>, EsError> {
+    fn get_array(&self) -> Result<Vec<EsValueFacade>, JsError> {
         panic!("i am not an array");
     }
     fn supports_stringify(&self) -> bool {
         false
     }
-    fn stringify(&self) -> Result<String, EsError> {
+    fn stringify(&self) -> Result<String, JsError> {
         unimplemented!()
     }
     fn is_error(&self) -> bool {
         false
     }
-    fn get_error(&self) -> EsError {
+    fn get_error(&self) -> JsError {
         unimplemented!()
     }
 }
@@ -229,12 +229,12 @@ impl EsProxyInstance {
 }
 
 impl EsValueConvertible for EsProxyInstance {
-    fn as_js_value(&mut self, q_ctx: &QuickJsContext) -> Result<JSValueRef, EsError> {
+    fn as_js_value(&mut self, q_ctx: &QuickJsContext) -> Result<JSValueRef, JsError> {
         let proxy_opt = reflection::get_proxy(q_ctx, self.class_name);
         if let Some(proxy) = proxy_opt {
             reflection::new_instance3(&proxy, self.instance_id, q_ctx)
         } else {
-            Err(EsError::new_string(format!(
+            Err(JsError::new_string(format!(
                 "no such proxy: {}",
                 self.class_name
             )))
@@ -243,7 +243,7 @@ impl EsValueConvertible for EsProxyInstance {
 }
 
 impl EsValueConvertible for EsNullValue {
-    fn as_js_value(&mut self, _q_ctx: &QuickJsContext) -> Result<JSValueRef, EsError> {
+    fn as_js_value(&mut self, _q_ctx: &QuickJsContext) -> Result<JSValueRef, JsError> {
         Ok(crate::quickjs_utils::new_null_ref())
     }
 
@@ -255,13 +255,13 @@ impl EsValueConvertible for EsNullValue {
         true
     }
 
-    fn stringify(&self) -> Result<String, EsError> {
+    fn stringify(&self) -> Result<String, JsError> {
         Ok("null".to_string())
     }
 }
 
 impl EsValueConvertible for EsUndefinedValue {
-    fn as_js_value(&mut self, _q_ctx: &QuickJsContext) -> Result<JSValueRef, EsError> {
+    fn as_js_value(&mut self, _q_ctx: &QuickJsContext) -> Result<JSValueRef, JsError> {
         Ok(crate::quickjs_utils::new_undefined_ref())
     }
 
@@ -273,7 +273,7 @@ impl EsValueConvertible for EsUndefinedValue {
         true
     }
 
-    fn stringify(&self) -> Result<String, EsError> {
+    fn stringify(&self) -> Result<String, JsError> {
         Ok("undefined".to_string())
     }
 }
@@ -473,7 +473,7 @@ fn pipe_promise_resolution_to_sender(
 }
 
 impl EsValueConvertible for CachedJSValueRef {
-    fn as_js_value(&mut self, q_ctx: &QuickJsContext) -> Result<JSValueRef, EsError> {
+    fn as_js_value(&mut self, q_ctx: &QuickJsContext) -> Result<JSValueRef, JsError> {
         Ok(q_ctx.with_cached_obj(self.cached_obj_id, |obj_ref| obj_ref))
     }
 
@@ -481,7 +481,7 @@ impl EsValueConvertible for CachedJSValueRef {
         self.es_type == EsType::Function
     }
 
-    fn invoke_function_sync(&self, mut args: Vec<EsValueFacade>) -> Result<EsValueFacade, EsError> {
+    fn invoke_function_sync(&self, mut args: Vec<EsValueFacade>) -> Result<EsValueFacade, JsError> {
         assert!(self.is_function());
 
         self.do_with_sync(move |_q_js_rt, q_ctx, obj_ref| {
@@ -498,7 +498,7 @@ impl EsValueConvertible for CachedJSValueRef {
     fn invoke_function(
         &self,
         mut args: Vec<EsValueFacade>,
-    ) -> EsValueFacadeFuture<EsValueFacade, EsError> {
+    ) -> EsValueFacadeFuture<EsValueFacade, JsError> {
         assert!(self.is_function());
         let ret = EsValueFacadeFuture::new();
         let tx = ret.get_resolver();
@@ -526,10 +526,10 @@ impl EsValueConvertible for CachedJSValueRef {
     fn invoke_function_batch_sync(
         &self,
         batch_args: Vec<Vec<EsValueFacade>>,
-    ) -> Vec<Result<EsValueFacade, EsError>> {
+    ) -> Vec<Result<EsValueFacade, JsError>> {
         assert!(self.is_function());
         self.do_with_sync(move |_q_js_rt, q_ctx, obj_ref| {
-            let mut res_vec: Vec<Result<EsValueFacade, EsError>> = vec![];
+            let mut res_vec: Vec<Result<EsValueFacade, JsError>> = vec![];
             for mut args in batch_args {
                 let mut ref_args = vec![];
                 for arg in args.iter_mut() {
@@ -554,7 +554,7 @@ impl EsValueConvertible for CachedJSValueRef {
     }
 
     // todo rewrite to Future
-    fn invoke_function_batch(&self, batch_args: Vec<Vec<EsValueFacade>>) -> Result<(), EsError> {
+    fn invoke_function_batch(&self, batch_args: Vec<Vec<EsValueFacade>>) -> Result<(), JsError> {
         assert!(self.is_function());
         self.do_with_sync(move |_q_js_rt, q_ctx, obj_ref| {
             for mut args in batch_args {
@@ -607,24 +607,23 @@ impl EsValueConvertible for CachedJSValueRef {
         then: PromiseReactionType,
         catch: PromiseReactionType,
         finally: Option<Box<dyn Fn() + Send + 'static>>,
-    ) -> Result<(), EsError> {
+    ) -> Result<(), JsError> {
         assert!(self.is_promise());
         self.do_with_sync(move |_q_js_rt, q_ctx, prom_ref| {
             let then_ref = if let Some(then_fn) = then {
                 let then_fn_rc = Rc::new(then_fn);
 
-                let then_fn_raw =
-                    move |q_ctx: &QuickJsContext,
-                          _this_ref: JSValueRef,
-                          mut args_ref: Vec<JSValueRef>| {
-                        let then_fn_rc = then_fn_rc.clone();
-                        let val_ref = args_ref.remove(0);
+                let then_fn_raw = move |q_ctx: &QuickJsContext,
+                                        _this_ref: &JSValueRef,
+                                        args_ref: &[JSValueRef]| {
+                    let then_fn_rc = then_fn_rc.clone();
+                    let val_ref = &args_ref[0];
 
-                        let val_esvf = EsValueFacade::from_jsval(q_ctx, &val_ref)?;
+                    let val_esvf = EsValueFacade::from_jsval(q_ctx, val_ref)?;
 
-                        then_fn_rc(val_esvf)?;
-                        Ok(crate::quickjs_utils::new_null_ref())
-                    };
+                    then_fn_rc(val_esvf)?;
+                    Ok(crate::quickjs_utils::new_null_ref())
+                };
                 let t = functions::new_function_q(q_ctx, "", then_fn_raw, 1)
                     .ok()
                     .expect("could not create function");
@@ -635,32 +634,40 @@ impl EsValueConvertible for CachedJSValueRef {
 
             let catch_ref = if let Some(catch_fn) = catch {
                 let catch_fn_rc = Rc::new(catch_fn);
-                let catch_fn_raw =
-                    move |q_ctx: &QuickJsContext, _this_ref, mut args_ref: Vec<JSValueRef>| {
-                        let val_ref = args_ref.remove(0);
+
+                let t = functions::new_function_q(
+                    q_ctx,
+                    "",
+                    move |q_ctx: &QuickJsContext, _this_ref, args_ref: &[JSValueRef]| {
+                        let val_ref = &args_ref[0];
                         let catch_fn_rc = catch_fn_rc.clone();
 
-                        let val_esvf = EsValueFacade::from_jsval(q_ctx, &val_ref)?;
+                        let val_esvf = EsValueFacade::from_jsval(q_ctx, val_ref)?;
 
                         catch_fn_rc(val_esvf)?;
                         Ok(crate::quickjs_utils::new_null_ref())
-                    };
-                let t = functions::new_function_q(q_ctx, "", catch_fn_raw, 1)
-                    .ok()
-                    .expect("could not create function");
+                    },
+                    1,
+                )
+                .ok()
+                .expect("could not create function");
                 Some(t)
             } else {
                 None
             };
 
             let finally_ref = if let Some(finally_fn) = finally {
-                let finally_fn_raw = move |_q_ctx: &QuickJsContext, _this_ref, _args_ref| {
-                    finally_fn();
-                    Ok(crate::quickjs_utils::new_null_ref())
-                };
-                let t = functions::new_function_q(q_ctx, "", finally_fn_raw, 0)
-                    .ok()
-                    .expect("could not create function");
+                let t = functions::new_function_q(
+                    q_ctx,
+                    "",
+                    move |_q_ctx: &QuickJsContext, _this_ref, _args_ref| {
+                        finally_fn();
+                        Ok(crate::quickjs_utils::new_null_ref())
+                    },
+                    0,
+                )
+                .ok()
+                .expect("could not create function");
                 Some(t)
             } else {
                 None
@@ -678,7 +685,7 @@ impl EsValueConvertible for CachedJSValueRef {
         self.es_type == EsType::Object
     }
 
-    fn get_object(&self) -> Result<HashMap<String, EsValueFacade>, EsError> {
+    fn get_object(&self) -> Result<HashMap<String, EsValueFacade>, JsError> {
         assert!(self.is_object());
         self.do_with_sync(|_q_js_rt, q_ctx, obj_ref| {
             let mut ret = HashMap::new();
@@ -698,7 +705,7 @@ impl EsValueConvertible for CachedJSValueRef {
         self.es_type == EsType::Array
     }
 
-    fn get_array(&self) -> Result<Vec<EsValueFacade>, EsError> {
+    fn get_array(&self) -> Result<Vec<EsValueFacade>, JsError> {
         assert!(self.is_array());
 
         self.do_with_sync(|_q_js_rt, q_ctx, obj_ref| {
@@ -718,7 +725,7 @@ impl EsValueConvertible for CachedJSValueRef {
         true
     }
 
-    fn stringify(&self) -> Result<String, EsError> {
+    fn stringify(&self) -> Result<String, JsError> {
         assert!(self.supports_stringify());
         self.do_with_sync(|_q_js_rt, q_ctx, obj_ref| {
             let res = stringify_q(q_ctx, &obj_ref, None)?;
@@ -730,16 +737,16 @@ impl EsValueConvertible for CachedJSValueRef {
         self.es_type == EsType::Error
     }
 
-    fn get_error(&self) -> EsError {
+    fn get_error(&self) -> JsError {
         assert!(self.is_error());
         self.do_with_sync(|_q_js_rt, q_ctx, obj_ref| unsafe {
-            error_to_eserror(q_ctx.context, &obj_ref)
+            error_to_js_error(q_ctx.context, &obj_ref)
         })
     }
 }
 
 impl EsValueConvertible for String {
-    fn as_js_value(&mut self, q_ctx: &QuickJsContext) -> Result<JSValueRef, EsError> {
+    fn as_js_value(&mut self, q_ctx: &QuickJsContext) -> Result<JSValueRef, JsError> {
         crate::quickjs_utils::primitives::from_string_q(q_ctx, self.as_str())
     }
 
@@ -755,13 +762,13 @@ impl EsValueConvertible for String {
         true
     }
 
-    fn stringify(&self) -> Result<String, EsError> {
+    fn stringify(&self) -> Result<String, JsError> {
         Ok(format!("\"{}\"", self.as_str().replace('"', "\\\"")))
     }
 }
 
 impl EsValueConvertible for i32 {
-    fn as_js_value(&mut self, _q_ctx: &QuickJsContext) -> Result<JSValueRef, EsError> {
+    fn as_js_value(&mut self, _q_ctx: &QuickJsContext) -> Result<JSValueRef, JsError> {
         Ok(crate::quickjs_utils::primitives::from_i32(*self))
     }
 
@@ -777,13 +784,13 @@ impl EsValueConvertible for i32 {
         true
     }
 
-    fn stringify(&self) -> Result<String, EsError> {
+    fn stringify(&self) -> Result<String, JsError> {
         Ok(format!("{}", self))
     }
 }
 
 impl EsValueConvertible for bool {
-    fn as_js_value(&mut self, _q_ctx: &QuickJsContext) -> Result<JSValueRef, EsError> {
+    fn as_js_value(&mut self, _q_ctx: &QuickJsContext) -> Result<JSValueRef, JsError> {
         Ok(crate::quickjs_utils::primitives::from_bool(*self))
     }
 
@@ -799,13 +806,13 @@ impl EsValueConvertible for bool {
         true
     }
 
-    fn stringify(&self) -> Result<String, EsError> {
+    fn stringify(&self) -> Result<String, JsError> {
         Ok(format!("{}", self))
     }
 }
 
 impl EsValueConvertible for f64 {
-    fn as_js_value(&mut self, _q_ctx: &QuickJsContext) -> Result<JSValueRef, EsError> {
+    fn as_js_value(&mut self, _q_ctx: &QuickJsContext) -> Result<JSValueRef, JsError> {
         Ok(crate::quickjs_utils::primitives::from_f64(*self))
     }
     fn is_f64(&self) -> bool {
@@ -820,13 +827,13 @@ impl EsValueConvertible for f64 {
         true
     }
 
-    fn stringify(&self) -> Result<String, EsError> {
+    fn stringify(&self) -> Result<String, JsError> {
         Ok(format!("{}", self))
     }
 }
 
 impl EsValueConvertible for Vec<EsValueFacade> {
-    fn as_js_value(&mut self, q_ctx: &QuickJsContext) -> Result<JSValueRef, EsError> {
+    fn as_js_value(&mut self, q_ctx: &QuickJsContext) -> Result<JSValueRef, JsError> {
         // create the array
 
         let arr = crate::quickjs_utils::arrays::create_array_q(q_ctx)
@@ -846,7 +853,7 @@ impl EsValueConvertible for Vec<EsValueFacade> {
 }
 
 impl EsValueConvertible for HashMap<String, EsValueFacade> {
-    fn as_js_value(&mut self, q_ctx: &QuickJsContext) -> Result<JSValueRef, EsError> {
+    fn as_js_value(&mut self, q_ctx: &QuickJsContext) -> Result<JSValueRef, JsError> {
         // create new obj
         let obj_ref = crate::quickjs_utils::objects::create_object_q(q_ctx)
             .ok()
@@ -993,11 +1000,11 @@ impl EsPromiseResolvableHandle {
             });
         }
     }
-    fn set_info(&self, es_rt: &Arc<EsRuntime>, id: usize, context_id: &str) -> Result<(), EsError> {
+    fn set_info(&self, es_rt: &Arc<EsRuntime>, id: usize, context_id: &str) -> Result<(), JsError> {
         let resolution_opt: Option<Result<EsValueFacade, EsValueFacade>> =
             self.with_inner(|inner| {
                 if inner.js_info.is_some() {
-                    Err(EsError::new_str("info was already set"))
+                    Err(JsError::new_str("info was already set"))
                 } else {
                     // set info
                     inner.js_info = Some(EsPromiseResolvableHandleInfo {
@@ -1095,13 +1102,13 @@ impl EsFunction {
     /// ```rust
     /// use quickjs_runtime::esvalue::{EsFunction, EsValueConvertible, ES_NULL, EsValueFacade};
     /// use quickjs_runtime::esruntimebuilder::EsRuntimeBuilder;
-    /// use quickjs_runtime::esscript::EsScript;
+    /// use hirofa_utils::js_utils::Script;
     /// async fn do_something(args: Vec<EsValueFacade>) -> Result<EsValueFacade, String> {
     ///     Ok(123.to_es_value_facade())
     /// }
     /// let func_esvf = EsFunction::new_async("my_callback", do_something).to_es_value_facade();
     /// let rt = EsRuntimeBuilder::new().build();
-    /// rt.eval_sync(EsScript::new("new_async.es", "this.test_func = function(cb){return cb();};")).ok().expect("func invo failed");
+    /// rt.eval_sync(Script::new("new_async.es", "this.test_func = function(cb){return cb();};")).ok().expect("func invo failed");
     /// let func_res = rt.call_function_sync(vec![], "test_func", vec![func_esvf]).ok().expect("func invo failed2");
     /// let ret = func_res.get_promise_result_sync().ok().expect("do_something returned err");
     /// assert_eq!(ret.get_i32(), 123);
@@ -1125,7 +1132,7 @@ impl EsFunction {
 }
 
 impl EsValueConvertible for EsFunction {
-    fn as_js_value(&mut self, q_ctx: &QuickJsContext) -> Result<JSValueRef, EsError> {
+    fn as_js_value(&mut self, q_ctx: &QuickJsContext) -> Result<JSValueRef, JsError> {
         let func_arc_mtx = self.method.clone();
 
         new_function_q(
@@ -1140,7 +1147,7 @@ impl EsValueConvertible for EsFunction {
 
                 let func = &*func_arc_mtx.lock().unwrap();
 
-                let mut res: EsValueFacade = func(args_facades).map_err(EsError::new_string)?;
+                let mut res: EsValueFacade = func(args_facades).map_err(JsError::new_string)?;
                 res.as_js_value(q_ctx)
             },
             1,
@@ -1154,7 +1161,7 @@ impl EsValueConvertible for EsFunction {
 /// use quickjs_runtime::esruntimebuilder::EsRuntimeBuilder;
 /// use quickjs_runtime::esvalue::{EsPromise, EsValueConvertible};
 /// use std::time::Duration;
-/// use quickjs_runtime::esscript::EsScript;
+/// use hirofa_utils::js_utils::Script;
 /// use log::LevelFilter;
 ///
 /// let rt = EsRuntimeBuilder::new().build();
@@ -1164,7 +1171,7 @@ impl EsValueConvertible for EsFunction {
 ///         Ok(9463.to_es_value_facade())
 ///     }).to_es_value_facade())
 /// });
-/// rt.eval_sync(EsScript::new("test_prom.es", "let p765 = my.comp.create_prom(); p765.then((p_res) => {console.log('got ' + p_res)});")).ok().expect("script failed");
+/// rt.eval_sync(Script::new("test_prom.es", "let p765 = my.comp.create_prom(); p765.then((p_res) => {console.log('got ' + p_res)});")).ok().expect("script failed");
 /// std::thread::sleep(Duration::from_secs(2));
 /// ```
 pub struct EsPromise {
@@ -1201,7 +1208,7 @@ impl EsPromise {
     /// ```rust
     /// use quickjs_runtime::esruntimebuilder::EsRuntimeBuilder;
     /// use quickjs_runtime::esvalue::{EsPromise, EsValueConvertible};
-    /// use quickjs_runtime::esscript::EsScript;
+    /// use hirofa_utils::js_utils::Script;
     /// use std::time::Duration;
     ///
     /// async fn a(i: i32) -> i32 {
@@ -1223,7 +1230,7 @@ impl EsPromise {
     /// .expect("setfunction failed");
     ///
     /// let res_prom = rt
-    ///     .eval_sync(EsScript::new("testasync2.es", "(com.my.testasyncfunc(7))"))
+    ///     .eval_sync(Script::new("testasync2.es", "(com.my.testasyncfunc(7))"))
     ///     .ok()
     ///     .expect("script failed");
     /// let res_i32 = res_prom.get_promise_result_sync().expect("prom failed");
@@ -1256,12 +1263,12 @@ impl EsPromise {
     /// # Example
     /// ```rust
     /// use quickjs_runtime::esruntimebuilder::EsRuntimeBuilder;
-    /// use quickjs_runtime::esscript::EsScript;
+    /// use hirofa_utils::js_utils::Script;
     /// use std::time::Duration;
     /// use quickjs_runtime::esvalue::{EsPromise, EsValueConvertible};
     /// let rt = EsRuntimeBuilder::new().build();
     /// // prep a function which reacts to a promise
-    /// rt.eval_sync(EsScript::new("new_unresolving.es", "this.new_unresolving = function(prom){prom.then((res) => {console.log('promise resolved to %s', res);});};")).ok().expect("script failed");
+    /// rt.eval_sync(Script::new("new_unresolving.es", "this.new_unresolving = function(prom){prom.then((res) => {console.log('promise resolved to %s', res);});};")).ok().expect("script failed");
     /// // prep a EsPromise object
     /// let prom = EsPromise::new_unresolving();
     /// // get the handle
@@ -1289,7 +1296,7 @@ impl EsPromise {
 }
 
 impl EsValueConvertible for EsPromise {
-    fn as_js_value(&mut self, q_ctx: &QuickJsContext) -> Result<JSValueRef, EsError> {
+    fn as_js_value(&mut self, q_ctx: &QuickJsContext) -> Result<JSValueRef, JsError> {
         log::trace!("EsPromise::to_js_value");
 
         let prom_ref = promises::new_promise_q(q_ctx)?;
@@ -1313,17 +1320,17 @@ pub struct EsValueFacade {
 
 impl EsValueFacade {
     /// stringify the value
-    pub fn stringify(&self) -> Result<String, EsError> {
+    pub fn stringify(&self) -> Result<String, JsError> {
         self.convertible.stringify()
     }
 
     /// convert the value to a JSValueRef
-    pub fn as_js_value(&mut self, q_ctx: &QuickJsContext) -> Result<JSValueRef, EsError> {
+    pub fn as_js_value(&mut self, q_ctx: &QuickJsContext) -> Result<JSValueRef, JsError> {
         self.convertible.as_js_value(q_ctx)
     }
 
     /// convert a JSValueRef to an EsValueFacade
-    pub fn from_jsval(q_ctx: &QuickJsContext, value_ref: &JSValueRef) -> Result<Self, EsError> {
+    pub fn from_jsval(q_ctx: &QuickJsContext, value_ref: &JSValueRef) -> Result<Self, JsError> {
         log::trace!("EsValueFacade::from_jsval: tag:{}", value_ref.get_tag());
 
         let r = value_ref.borrow_value();
@@ -1367,7 +1374,7 @@ impl EsValueFacade {
             ,
             // BigIn
             TAG_BIG_INT => Ok(CachedJSValueRef::new(q_ctx, value_ref).to_es_value_facade()),
-            x => Err(EsError::new_string(format!(
+            x => Err(JsError::new_string(format!(
                 "Unhandled JS_TAG value: {}",
                 x
             ))),
@@ -1395,12 +1402,12 @@ impl EsValueFacade {
     }
 
     /// get the array value
-    pub fn get_array(&self) -> Result<Vec<EsValueFacade>, EsError> {
+    pub fn get_array(&self) -> Result<Vec<EsValueFacade>, JsError> {
         self.convertible.get_array()
     }
 
     /// get the object value
-    pub fn get_object(&self) -> Result<HashMap<String, EsValueFacade>, EsError> {
+    pub fn get_object(&self) -> Result<HashMap<String, EsValueFacade>, JsError> {
         self.convertible.get_object()
     }
 
@@ -1458,14 +1465,14 @@ impl EsValueFacade {
     pub fn invoke_function_sync(
         &self,
         arguments: Vec<EsValueFacade>,
-    ) -> Result<EsValueFacade, EsError> {
+    ) -> Result<EsValueFacade, JsError> {
         self.convertible.invoke_function_sync(arguments)
     }
     /// invoke the Function represented by this EsValueFacade
     pub async fn invoke_function(
         &self,
         arguments: Vec<EsValueFacade>,
-    ) -> Result<EsValueFacade, EsError> {
+    ) -> Result<EsValueFacade, JsError> {
         self.convertible.invoke_function(arguments).await
     }
 
@@ -1473,12 +1480,12 @@ impl EsValueFacade {
     pub fn invoke_function_batch_sync(
         &self,
         arguments: Vec<Vec<EsValueFacade>>,
-    ) -> Vec<Result<EsValueFacade, EsError>> {
+    ) -> Vec<Result<EsValueFacade, JsError>> {
         self.convertible.invoke_function_batch_sync(arguments)
     }
 
     /// invoke a function multiple times with a different set of arguments
-    pub fn invoke_function_batch(&self, arguments: Vec<Vec<EsValueFacade>>) -> Result<(), EsError> {
+    pub fn invoke_function_batch(&self, arguments: Vec<Vec<EsValueFacade>>) -> Result<(), JsError> {
         self.convertible.invoke_function_batch(arguments)
     }
 
@@ -1493,7 +1500,7 @@ impl EsValueFacade {
     /// # Example
     /// ```rust
     /// use quickjs_runtime::esruntimebuilder::EsRuntimeBuilder;
-    /// use quickjs_runtime::esscript::EsScript;
+    /// use hirofa_utils::js_utils::Script;
     /// use futures::executor::block_on;
     /// use quickjs_runtime::esvalue::EsValueFacade;
     /// pub async fn test_async(esvf: EsValueFacade) -> i32 {
@@ -1503,7 +1510,7 @@ impl EsValueFacade {
     /// }
     ///
     /// let rt = EsRuntimeBuilder::new().build();
-    /// let esvf = rt.eval_sync(EsScript::new("test_async_prom,es", "(new Promise((resolve, reject) => {setTimeout(() => {resolve(1360)}, 1000);}));")).ok().expect("script failed");
+    /// let esvf = rt.eval_sync(Script::new("test_async_prom,es", "(new Promise((resolve, reject) => {setTimeout(() => {resolve(1360)}, 1000);}));")).ok().expect("script failed");
     /// let i = block_on(test_async(esvf));
     /// assert_eq!(i, 1360);
     ///
@@ -1516,7 +1523,7 @@ impl EsValueFacade {
         self.convertible.is_error()
     }
 
-    pub fn get_error(&self) -> EsError {
+    pub fn get_error(&self) -> JsError {
         self.convertible.get_error()
     }
 }
@@ -1554,9 +1561,9 @@ pub mod tests {
     use crate::esruntime::tests::init_test_rt;
     use crate::esruntime::EsRuntime;
     use crate::esruntimebuilder::EsRuntimeBuilder;
-    use crate::esscript::EsScript;
     use crate::esvalue::{EsPromise, EsValueConvertible, EsValueFacade};
     use futures::executor::block_on;
+    use hirofa_utils::js_utils::Script;
     use std::sync::{Arc, Weak};
     use std::time::Duration;
 
@@ -1570,7 +1577,7 @@ pub mod tests {
     fn test_async_func() {
         let rt: Arc<EsRuntime> = init_test_rt();
         let func_esvf = rt
-            .eval_sync(EsScript::new(
+            .eval_sync(Script::new(
                 "test_async_func.es",
                 "(function someFunc(){return 147;});",
             ))
@@ -1583,7 +1590,7 @@ pub mod tests {
     #[test]
     fn test_promise() {
         let rt: Arc<EsRuntime> = init_test_rt();
-        let res = rt.eval_sync(EsScript::new(
+        let res = rt.eval_sync(Script::new(
             "test_promise.es",
             "(new Promise(function(resolve, reject){resolve(537);}));",
         ));
@@ -1617,7 +1624,7 @@ pub mod tests {
 
         let rt = EsRuntimeBuilder::new().build();
         let esvf = rt
-            .eval_sync(EsScript::new(
+            .eval_sync(Script::new(
                 "test_async_prom,es",
                 "(new Promise((resolve, reject) => {setTimeout(() => {resolve(1360)}, 1000);}));",
             ))
@@ -1630,7 +1637,7 @@ pub mod tests {
     async fn a(i: i32, rt_ref: Weak<EsRuntime>) -> i32 {
         let rt = rt_ref.upgrade().unwrap();
         let second_prom = rt
-            .eval(EsScript::new(
+            .eval(Script::new(
                 "o.es",
                 "(new Promise((resolve) => {resolve(321);}))",
             ))
@@ -1664,7 +1671,7 @@ pub mod tests {
         .expect("setfunction failed");
 
         let res_prom = rt
-            .eval_sync(EsScript::new("testasync2.es", "(com.my.testasyncfunc(7))"))
+            .eval_sync(Script::new("testasync2.es", "(com.my.testasyncfunc(7))"))
             .ok()
             .expect("script failed");
         let res_i32 = res_prom.get_promise_result_sync().expect("prom failed");
@@ -1675,7 +1682,7 @@ pub mod tests {
     fn test_stringify() {
         let rt = init_test_rt();
         let esvf = rt
-            .eval_sync(EsScript::new(
+            .eval_sync(Script::new(
                 "test_stringify.es",
                 "({a: 1, b: 'abc', c: true, d: {a: 1, b: 2}});",
             ))
@@ -1708,7 +1715,7 @@ pub mod tests {
     #[test]
     fn test_error() {
         let rt = init_test_rt();
-        let esvf = match rt.eval_sync(EsScript::new(
+        let esvf = match rt.eval_sync(Script::new(
             "test_err.es",
             "((async function() {throw Error('poof')})());",
         )) {
