@@ -1,10 +1,14 @@
-use crate::eserror::EsError;
-use crate::esscript::EsScript;
-use crate::quickjs_utils::{errors, functions, objects};
+use crate::quickjs_utils::primitives::{from_bool, from_f64, from_i32, from_string_q};
+use crate::quickjs_utils::promises::PromiseRef;
+use crate::quickjs_utils::{arrays, errors, functions, new_null_ref, objects};
 use crate::quickjsruntime::{make_cstring, QuickJsRuntime};
 use crate::reflection::{Proxy, ProxyInstanceInfo};
 use crate::valueref::{JSValueRef, TAG_EXCEPTION};
 use hirofa_utils::auto_id_map::AutoIdMap;
+use hirofa_utils::js_utils::adapters::proxies::JsProxy;
+use hirofa_utils::js_utils::adapters::JsRealmAdapter;
+use hirofa_utils::js_utils::JsError;
+use hirofa_utils::js_utils::Script;
 use libquickjs_sys as q;
 use std::cell::RefCell;
 use std::collections::HashMap;
@@ -98,21 +102,21 @@ impl QuickJsContext {
         namespace: Vec<&str>,
         func_name: &str,
         arguments: Vec<JSValueRef>,
-    ) -> Result<JSValueRef, EsError> {
+    ) -> Result<JSValueRef, JsError> {
         let namespace_ref = unsafe { objects::get_namespace(self.context, namespace, false) }?;
         functions::invoke_member_function_q(self, &namespace_ref, func_name, arguments)
     }
     /// evaluate a script
 
-    pub fn eval(&self, script: EsScript) -> Result<JSValueRef, EsError> {
+    pub fn eval(&self, script: Script) -> Result<JSValueRef, JsError> {
         unsafe { Self::eval_ctx(self.context, script) }
     }
     /// # Safety
     /// when passing a context ptr please be sure that the corresponding QuickJsContext is still active
     pub unsafe fn eval_ctx(
         context: *mut q::JSContext,
-        mut script: EsScript,
-    ) -> Result<JSValueRef, EsError> {
+        mut script: Script,
+    ) -> Result<JSValueRef, JsError> {
         log::debug!("q_js_rt.eval file {}", script.get_path());
 
         script = QuickJsRuntime::pre_process(script)?;
@@ -144,7 +148,7 @@ impl QuickJsContext {
                 log::debug!("eval_ctx failed: {}", ex);
                 Err(ex)
             } else {
-                Err(EsError::new_str("eval failed and could not get exception"))
+                Err(JsError::new_str("eval failed and could not get exception"))
             }
         } else {
             Ok(ret)
@@ -152,7 +156,7 @@ impl QuickJsContext {
     }
 
     /// evaluate a Module
-    pub fn eval_module(&self, script: EsScript) -> Result<JSValueRef, EsError> {
+    pub fn eval_module(&self, script: Script) -> Result<JSValueRef, JsError> {
         unsafe { Self::eval_module_ctx(self.context, script) }
     }
 
@@ -160,8 +164,8 @@ impl QuickJsContext {
     /// when passing a context ptr please be sure that the corresponding QuickJsContext is still active
     pub unsafe fn eval_module_ctx(
         context: *mut q::JSContext,
-        mut script: EsScript,
-    ) -> Result<JSValueRef, EsError> {
+        mut script: Script,
+    ) -> Result<JSValueRef, JsError> {
         log::debug!("q_js_rt.eval_module file {}", script.get_path());
 
         script = QuickJsRuntime::pre_process(script)?;
@@ -195,7 +199,7 @@ impl QuickJsContext {
                 log::debug!("eval_module_ctx failed: {}", ex);
                 Err(ex)
             } else {
-                Err(EsError::new_str(
+                Err(JsError::new_str(
                     "eval_module failed and could not get exception",
                 ))
             }
@@ -219,15 +223,15 @@ impl QuickJsContext {
         }
     }
 
-    /// Get the last exception from the runtime, and if present, convert it to a EsError.
-    pub fn get_exception_ctx(&self) -> Option<EsError> {
+    /// Get the last exception from the runtime, and if present, convert it to a JsError.
+    pub fn get_exception_ctx(&self) -> Option<JsError> {
         unsafe { errors::get_exception(self.context) }
     }
 
-    /// Get the last exception from the runtime, and if present, convert it to a EsError.
+    /// Get the last exception from the runtime, and if present, convert it to a JsError.
     /// # Safety
     /// When passing a context pointer please make sure the corresponding QuickJsContext is still valid
-    pub unsafe fn get_exception(context: *mut q::JSContext) -> Option<EsError> {
+    pub unsafe fn get_exception(context: *mut q::JSContext) -> Option<JsError> {
         errors::get_exception(context)
     }
 
@@ -309,12 +313,290 @@ impl Drop for QuickJsContext {
     }
 }
 
+impl JsRealmAdapter for QuickJsContext {
+    type JsRuntimeAdapterType = QuickJsRuntime;
+
+    fn js_eval(&self, script: Script) -> Result<JSValueRef, JsError> {
+        self.eval(script)
+    }
+
+    fn js_proxy_install(&self, _proxy: JsProxy<Self::JsRuntimeAdapterType>) {
+        unimplemented!()
+    }
+
+    fn js_proxy_instantiate(
+        &self,
+        _namespace: &[&str],
+        _class_name: &str,
+        _arguments: &[JSValueRef],
+    ) -> Result<JSValueRef, JsError> {
+        unimplemented!()
+    }
+
+    fn js_proxy_invoke_event(
+        &self,
+        _proxy_handle: &usize,
+        _event_id: &str,
+        _event_obj: &JSValueRef,
+    ) {
+        unimplemented!()
+    }
+
+    fn js_install_function(
+        &self,
+        namespace: &[&str],
+        name: &str,
+        js_function: fn(&Self, &JSValueRef, &[JSValueRef]) -> Result<JSValueRef, JsError>,
+        arg_count: u32,
+    ) -> Result<(), JsError> {
+        // todo namespace as slice?
+        let ns = self.js_get_namespace(&namespace)?;
+
+        let func = functions::new_function_q(self, name, js_function, arg_count)?;
+        self.js_object_set_property(&ns, name, &func)?;
+        Ok(())
+    }
+
+    fn js_install_closure<
+        F: Fn(&Self, &JSValueRef, &[JSValueRef]) -> Result<JSValueRef, JsError> + 'static,
+    >(
+        &self,
+        namespace: &[&str],
+        name: &str,
+        js_function: F,
+        arg_count: u32,
+    ) -> Result<(), JsError> {
+        // todo namespace as slice?
+        let ns = self.js_get_namespace(&namespace)?;
+
+        let func = functions::new_function_q(self, name, js_function, arg_count)?;
+        self.js_object_set_property(&ns, name, &func)?;
+        Ok(())
+    }
+
+    fn js_eval_module(&self, script: Script) -> Result<JSValueRef, JsError> {
+        self.eval_module(script)
+    }
+
+    fn js_get_namespace(&self, namespace: &[&str]) -> Result<JSValueRef, JsError> {
+        let namespace_vec = namespace.to_vec();
+        objects::get_namespace_q(self, namespace_vec, true)
+    }
+
+    fn js_function_invoke_by_name(
+        &self,
+        namespace: &[&str],
+        method_name: &str,
+        args: &[JSValueRef],
+    ) -> Result<JSValueRef, JsError> {
+        // todo see if we want to alter call_function
+        let ns_vec = namespace.to_vec();
+        let args_vec = args.to_vec();
+
+        self.call_function(ns_vec, method_name, args_vec)
+    }
+
+    fn js_function_invoke_member_by_name(
+        &self,
+        this_obj: &JSValueRef,
+        method_name: &str,
+        args: &[JSValueRef],
+    ) -> Result<JSValueRef, JsError> {
+        let args_vec = args.to_vec();
+        functions::invoke_member_function_q(self, this_obj, method_name, args_vec)
+    }
+
+    fn js_function_invoke(
+        &self,
+        this_obj: Option<&JSValueRef>,
+        function_obj: &JSValueRef,
+        args: &[JSValueRef],
+    ) -> Result<JSValueRef, JsError> {
+        let args_vec = args.to_vec();
+        functions::call_function_q(self, function_obj, args_vec, this_obj)
+    }
+
+    fn js_function_create<
+        F: Fn(&Self, &JSValueRef, &[JSValueRef]) -> Result<JSValueRef, JsError> + 'static,
+    >(
+        &self,
+        name: &str,
+        js_function: F,
+        arg_count: u32,
+    ) -> Result<JSValueRef, JsError> {
+        functions::new_function_q(self, name, js_function, arg_count)
+    }
+
+    fn js_object_delete_property(
+        &self,
+        object: &JSValueRef,
+        property_name: &str,
+    ) -> Result<(), JsError> {
+        // todo impl a real delete_prop
+        objects::set_property_q(self, object, property_name, &new_null_ref())
+    }
+
+    fn js_object_set_property(
+        &self,
+        object: &JSValueRef,
+        property_name: &str,
+        property: &JSValueRef,
+    ) -> Result<(), JsError> {
+        objects::set_property_q(self, object, property_name, property)
+    }
+
+    fn js_object_get_property(
+        &self,
+        object: &JSValueRef,
+        property_name: &str,
+    ) -> Result<JSValueRef, JsError> {
+        objects::get_property_q(self, object, property_name)
+    }
+
+    fn js_object_create(&self) -> Result<JSValueRef, JsError> {
+        objects::create_object_q(self)
+    }
+
+    fn js_object_construct(
+        &self,
+        _constructor: &JSValueRef,
+        _args: &[JSValueRef],
+    ) -> Result<JSValueRef, JsError> {
+        unimplemented!()
+    }
+
+    fn js_object_get_properties(&self, object: &JSValueRef) -> Result<Vec<String>, JsError> {
+        let props = objects::get_own_property_names_q(self, object)?;
+        let mut ret = vec![];
+        for x in 0..props.len() {
+            let prop = props.get_name(x)?;
+            ret.push(prop);
+        }
+        Ok(ret)
+    }
+
+    fn js_object_traverse<F, R>(&self, object: &JSValueRef, visitor: F) -> Result<Vec<R>, JsError>
+    where
+        F: Fn(&str, &JSValueRef) -> Result<R, JsError>,
+    {
+        objects::traverse_properties_q(self, object, visitor)
+    }
+
+    fn js_array_get_element(&self, array: &JSValueRef, index: u32) -> Result<JSValueRef, JsError> {
+        arrays::get_element_q(self, array, index)
+    }
+
+    fn js_array_set_element(
+        &self,
+        array: &JSValueRef,
+        index: u32,
+        element: JSValueRef,
+    ) -> Result<(), JsError> {
+        arrays::set_element_q(self, array, index, element)
+    }
+
+    fn js_array_get_length(&self, array: &JSValueRef) -> Result<u32, JsError> {
+        arrays::get_length_q(self, array)
+    }
+
+    fn js_array_create(&self) -> Result<JSValueRef, JsError> {
+        arrays::create_array_q(self)
+    }
+
+    fn js_array_traverse<F, R>(&self, array: &JSValueRef, visitor: F) -> Result<Vec<R>, JsError>
+    where
+        F: Fn(u32, &JSValueRef) -> Result<R, JsError>,
+    {
+        // todo impl real traverse methods
+        let mut ret = vec![];
+        for x in 0..arrays::get_length_q(self, array)? {
+            let val = arrays::get_element_q(self, array, x)?;
+            ret.push(visitor(x, &val)?)
+        }
+        Ok(ret)
+    }
+
+    fn js_null_create(&self) -> Result<JSValueRef, JsError> {
+        Ok(crate::quickjs_utils::new_null_ref())
+    }
+
+    fn js_undefined_create(&self) -> Result<JSValueRef, JsError> {
+        Ok(crate::quickjs_utils::new_undefined_ref())
+    }
+
+    fn js_i32_create(&self, val: i32) -> Result<JSValueRef, JsError> {
+        Ok(from_i32(val))
+    }
+
+    fn js_string_create(&self, val: &str) -> Result<JSValueRef, JsError> {
+        from_string_q(self, val)
+    }
+
+    fn js_boolean_create(&self, val: bool) -> Result<JSValueRef, JsError> {
+        Ok(from_bool(val))
+    }
+
+    fn js_f64_create(&self, val: f64) -> Result<JSValueRef, JsError> {
+        Ok(from_f64(val))
+    }
+
+    fn js_promise_create(&self) -> Result<PromiseRef, JsError> {
+        crate::quickjs_utils::promises::new_promise_q(self)
+    }
+
+    fn js_cache_add(&self, object: JSValueRef) -> i32 {
+        self.cache_object(object)
+    }
+
+    fn js_cache_dispose(&self, id: i32) {
+        let _ = self.consume_cached_obj(id);
+    }
+
+    fn js_cache_with<C, R>(&self, id: i32, consumer: C) -> R
+    where
+        C: FnOnce(&JSValueRef) -> R,
+    {
+        self.with_cached_obj(id, |obj| consumer(&obj))
+    }
+
+    fn js_cache_consume(&self, id: i32) -> JSValueRef {
+        self.consume_cached_obj(id)
+    }
+
+    fn js_instance_of(&self, object: &JSValueRef, constructor: &JSValueRef) -> bool {
+        objects::is_instance_of_q(self, object, constructor)
+    }
+}
+
 #[cfg(test)]
 pub mod tests {
+    use crate::esruntime::tests::init_test_rt;
     use crate::esruntimebuilder::EsRuntimeBuilder;
-    use crate::esscript::EsScript;
     use crate::quickjs_utils;
+    use crate::quickjs_utils::primitives::to_i32;
     use crate::quickjs_utils::{functions, get_global_q, objects};
+    use hirofa_utils::js_utils::Script;
+
+    #[test]
+    fn test_eval() {
+        let rt = init_test_rt();
+        rt.exe_rt_task_in_event_loop(|q_js_rt| {
+            let q_ctx = q_js_rt.get_main_context();
+            let res = q_ctx.eval(Script::new("test_eval.es", "(1 + 1);"));
+
+            match res {
+                Ok(res) => {
+                    log::info!("script ran ok: {:?}", res);
+                    assert!(res.is_i32());
+                    assert_eq!(to_i32(&res).ok().expect("conversion failed"), 2);
+                }
+                Err(e) => {
+                    log::error!("script failed: {}", e);
+                    panic!("script failed");
+                }
+            }
+        });
+    }
 
     #[test]
     fn test_multi_ctx() {
@@ -326,30 +608,30 @@ pub mod tests {
             let ctx_a = q_js_rt.get_context("a");
             let ctx_b = q_js_rt.get_context("b");
             ctx_a
-                .eval(EsScript::new("a.es", "this.a = 1"))
+                .eval(Script::new("a.es", "this.a = 1"))
                 .ok()
                 .expect("script failed");
             ctx_b
-                .eval(EsScript::new("a.es", "this.b = 1"))
+                .eval(Script::new("a.es", "this.b = 1"))
                 .ok()
                 .expect("script failed");
             let v = ctx_a
-                .eval(EsScript::new("a2.es", "this.a;"))
+                .eval(Script::new("a2.es", "this.a;"))
                 .ok()
                 .expect("script failed");
             assert!(v.is_i32());
             let v2 = ctx_b
-                .eval(EsScript::new("b2.es", "this.a;"))
+                .eval(Script::new("b2.es", "this.a;"))
                 .ok()
                 .expect("script failed");
             assert!(v2.is_null_or_undefined());
             let v3 = ctx_a
-                .eval(EsScript::new("a2.es", "this.b;"))
+                .eval(Script::new("a2.es", "this.b;"))
                 .ok()
                 .expect("script failed");
             assert!(v3.is_null_or_undefined());
             let v4 = ctx_b
-                .eval(EsScript::new("b2.es", "this.b;"))
+                .eval(Script::new("b2.es", "this.b;"))
                 .ok()
                 .expect("script failed");
             assert!(v4.is_i32());
@@ -360,7 +642,7 @@ pub mod tests {
             q_js_rt.gc();
             let ctx_a = q_js_rt.get_context("a");
             let v = ctx_a
-                .eval(EsScript::new("a2.es", "this.a;"))
+                .eval(Script::new("a2.es", "this.a;"))
                 .ok()
                 .expect("script failed");
             assert!(v.is_i32());
@@ -391,7 +673,7 @@ pub mod tests {
             q_js_rt.gc();
             let ctx_a = q_js_rt.get_context("a");
             let v = ctx_a
-                .eval(EsScript::new("a2.es", "this.a;"))
+                .eval(Script::new("a2.es", "this.a;"))
                 .ok()
                 .expect("script failed");
             assert!(v.is_i32());
@@ -402,7 +684,7 @@ pub mod tests {
             q_js_rt.gc();
             let ctx_a = q_js_rt.get_context("a");
             let v = ctx_a
-                .eval(EsScript::new("a2.es", "this.a;"))
+                .eval(Script::new("a2.es", "this.a;"))
                 .ok()
                 .expect("script failed");
             assert!(v.is_i32());
