@@ -1,15 +1,18 @@
 // store in thread_local
 
-use crate::eserror::EsError;
-use crate::esruntime::{EsRuntime, ScriptPreProcessor};
-use crate::esscript::EsScript;
+use crate::esruntime::EsRuntime;
 use crate::quickjs_utils::modules::{
     add_module_export, compile_module, get_module_def, get_module_name, new_module,
     set_module_export,
 };
+use crate::quickjs_utils::promises::PromiseRef;
 use crate::quickjs_utils::{gc, interrupthandler, modules, promises};
 use crate::quickjscontext::QuickJsContext;
 use crate::valueref::JSValueRef;
+use hirofa_utils::js_utils::adapters::JsRuntimeAdapter;
+use hirofa_utils::js_utils::JsError;
+use hirofa_utils::js_utils::Script;
+use hirofa_utils::js_utils::ScriptPreProcessor;
 use libquickjs_sys as q;
 use std::cell::RefCell;
 use std::collections::HashMap;
@@ -28,7 +31,7 @@ pub trait ModuleLoader {
         &self,
         q_ctx: &QuickJsContext,
         absolute_path: &str,
-    ) -> Result<*mut q::JSModuleDef, EsError>;
+    ) -> Result<*mut q::JSModuleDef, JsError>;
     /// has module is used to check if a loader can provide a certain module, this is currently used to check which loader should init a native module
     fn has_module(&self, q_ctx: &QuickJsContext, absolute_path: &str) -> bool;
     /// init a module, currently used to init native modules
@@ -38,7 +41,7 @@ pub trait ModuleLoader {
         &self,
         q_ctx: &QuickJsContext,
         module: *mut q::JSModuleDef,
-    ) -> Result<(), EsError>;
+    ) -> Result<(), JsError>;
 }
 
 // these are the external (util) loaders (todo move these to esruntime?)
@@ -72,10 +75,10 @@ impl ModuleLoader for ScriptModuleLoaderAdapter {
         &self,
         q_ctx: &QuickJsContext,
         absolute_path: &str,
-    ) -> Result<*mut q::JSModuleDef, EsError> {
+    ) -> Result<*mut q::JSModuleDef, JsError> {
         let code = self.inner.load_module(absolute_path);
 
-        let mut script = EsScript::new(absolute_path, code.as_str());
+        let mut script = Script::new(absolute_path, code.as_str());
         script = QuickJsRuntime::pre_process(script)?;
 
         let compiled_module = unsafe { compile_module(q_ctx.context, script)? };
@@ -91,7 +94,7 @@ impl ModuleLoader for ScriptModuleLoaderAdapter {
         &self,
         _q_ctx: &QuickJsContext,
         _module: *mut q::JSModuleDef,
-    ) -> Result<(), EsError> {
+    ) -> Result<(), JsError> {
         Ok(())
     }
 }
@@ -124,7 +127,7 @@ impl ModuleLoader for NativeModuleLoaderAdapter {
         &self,
         q_ctx: &QuickJsContext,
         absolute_path: &str,
-    ) -> Result<*mut q::JSModuleDef, EsError> {
+    ) -> Result<*mut q::JSModuleDef, JsError> {
         // create module
         let module = unsafe { new_module(q_ctx.context, absolute_path, Some(native_module_init))? };
 
@@ -144,7 +147,7 @@ impl ModuleLoader for NativeModuleLoaderAdapter {
         &self,
         q_ctx: &QuickJsContext,
         module: *mut q::JSModuleDef,
-    ) -> Result<(), EsError> {
+    ) -> Result<(), JsError> {
         let module_name = get_module_name(q_ctx.context, module)?;
 
         for (name, val) in self.inner.get_module_exports(q_ctx, module_name.as_str()) {
@@ -216,7 +219,7 @@ thread_local! {
 }
 
 pub type ContextInitHooks =
-    Vec<Box<dyn Fn(&QuickJsRuntime, &QuickJsContext) -> Result<(), EsError>>>;
+    Vec<Box<dyn Fn(&QuickJsRuntime, &QuickJsContext) -> Result<(), JsError>>>;
 
 pub struct QuickJsRuntime {
     pub(crate) runtime: *mut q::JSRuntime,
@@ -238,18 +241,18 @@ impl QuickJsRuntime {
         })
     }
 
-    pub(crate) fn pre_process(mut script: EsScript) -> Result<EsScript, EsError> {
+    pub(crate) fn pre_process(mut script: Script) -> Result<Script, JsError> {
         Self::do_with(|q_js_rt| {
             for pp in &q_js_rt.script_pre_processors {
-                script = pp.process(script)?;
+                pp.process(&mut script)?;
             }
             Ok(script)
         })
     }
 
-    pub fn add_context_init_hook<H>(&self, hook: H) -> Result<(), EsError>
+    pub fn add_context_init_hook<H>(&self, hook: H) -> Result<(), JsError>
     where
-        H: Fn(&QuickJsRuntime, &QuickJsContext) -> Result<(), EsError> + 'static,
+        H: Fn(&QuickJsRuntime, &QuickJsContext) -> Result<(), JsError> + 'static,
     {
         for ctx in self.contexts.values() {
             hook(self, ctx)?;
@@ -262,8 +265,8 @@ impl QuickJsRuntime {
     // todo, this needs to be static, create a context, then borrowmut and add it (do not borrow mut while instantiating context)
     // so actually needs to be called in a plain job to inner.TaskManager and not by add_to_esEventquueue
     // EsRuntime should have a util to do that
-    // EsRuntime should have extra methods like eval_sync_ctx(ctx: &str, script: &EsScript) etc
-    pub fn create_context(id: &str) -> Result<(), EsError> {
+    // EsRuntime should have extra methods like eval_sync_ctx(ctx: &str, script: &Script) etc
+    pub fn create_context(id: &str) -> Result<(), JsError> {
         let ctx = Self::do_with(|q_js_rt| {
             assert!(!q_js_rt.has_context(id));
             QuickJsContext::new(id.to_string(), q_js_rt)
@@ -360,10 +363,6 @@ impl QuickJsRuntime {
         modules::set_module_loader(&q_rt);
         promises::init_promise_rejection_tracker(&q_rt);
 
-        if q_rt.interrupt_handler.is_some() {
-            interrupthandler::init(&q_rt);
-        }
-
         let main_ctx = QuickJsContext::new("__main__".to_string(), &q_rt);
         q_rt.contexts.insert("__main__".to_string(), main_ctx);
 
@@ -374,7 +373,10 @@ impl QuickJsRuntime {
         &mut self,
         interrupt_handler: I,
     ) -> &mut Self {
+        println!("qjsrt_set_interrupt_handler");
+
         self.interrupt_handler = Some(Box::new(interrupt_handler));
+        interrupthandler::init(self);
         self
     }
 
@@ -467,7 +469,7 @@ impl QuickJsRuntime {
         flag > 0
     }
 
-    pub fn run_pending_job(&self) -> Result<(), EsError> {
+    pub fn run_pending_job(&self) -> Result<(), JsError> {
         let mut ctx: *mut q::JSContext = std::ptr::null_mut();
         let flag = unsafe {
             // ctx is a return arg here
@@ -475,7 +477,7 @@ impl QuickJsRuntime {
         };
         if flag < 0 {
             let e = unsafe { QuickJsContext::get_exception(ctx) }
-                .unwrap_or_else(|| EsError::new_str("Unknown exception while running pending job"));
+                .unwrap_or_else(|| JsError::new_str("Unknown exception while running pending job"));
             return Err(e);
         }
         Ok(())
@@ -486,12 +488,12 @@ impl QuickJsRuntime {
     }
 
     /// this method tries to load a module script using the runtimes script_module loaders
-    pub fn load_module_script_opt(&self, ref_path: &str, path: &str) -> Option<EsScript> {
+    pub fn load_module_script_opt(&self, ref_path: &str, path: &str) -> Option<Script> {
         for loader in &self.script_module_loaders {
             let i = &loader.inner;
             if let Some(normalized) = i.normalize_path(ref_path, path) {
                 let code = i.load_module(normalized.as_str());
-                return Some(EsScript::new(normalized.as_str(), code.as_str()));
+                return Some(Script::new(normalized.as_str(), code.as_str()));
             }
         }
 
@@ -513,12 +515,34 @@ impl Drop for QuickJsRuntime {
     }
 }
 
+impl JsRuntimeAdapter for QuickJsRuntime {
+    type JsValueAdapterType = JSValueRef;
+    type JsPromiseAdapterType = PromiseRef;
+    type JsRealmAdapterType = QuickJsContext;
+
+    fn js_create_realm(&self, _id: &str) -> Result<&Self::JsRealmAdapterType, JsError> {
+        todo!();
+    }
+
+    fn js_get_realm(&self, id: &str) -> Option<&Self::JsRealmAdapterType> {
+        if self.has_context(id) {
+            Some(self.get_context(id))
+        } else {
+            None
+        }
+    }
+
+    fn js_get_main_realm(&self) -> &Self::JsRealmAdapterType {
+        self.get_main_context()
+    }
+}
+
 /// Helper for creating CStrings.
-pub(crate) fn make_cstring(value: &str) -> Result<CString, EsError> {
+pub(crate) fn make_cstring(value: &str) -> Result<CString, JsError> {
     let res = CString::new(value);
     match res {
         Ok(val) => Ok(val),
-        Err(_) => Err(EsError::new_string(format!(
+        Err(_) => Err(JsError::new_string(format!(
             "could not create cstring from {}",
             value
         ))),
